@@ -1,9 +1,8 @@
+#pragma once
 #ifndef OPTIMIZATION_PROBLEM_H
 #define OPTIMIZATION_PROBLEM_H
 
 #include "package.h"
-#include <vector>
-#include <algorithm>
 
 class OPTIMIZATIONPROBLEM
 {
