@@ -78,7 +78,7 @@ test_that("solution (compressed formulation, single zone)", {
        add_max_phylo_div_objective(budget = budget, tree = tr) %>%
        add_absolute_targets(c(2, 12, 2)) %>%
        add_locked_out_constraints(locked_out) %>%
-       add_default_solver(gap = 0)
+       add_default_solver(gap = 0, verbose = FALSE)
   # solve problem
   s1 <- solve(p)
   s2 <- solve(p)
@@ -181,7 +181,7 @@ test_that("solution (expanded formulation, single zone)", {
        add_max_phylo_div_objective(budget = budget, tree = tr) %>%
        add_absolute_targets(c(2, 12, 2)) %>%
        add_locked_out_constraints(locked_out) %>%
-       add_default_solver(gap = 0)
+       add_default_solver(gap = 0, verbose = FALSE)
   # solve problem
   s <- solve(p, compressed_formulation = FALSE)
   # test for correct solution
@@ -263,7 +263,7 @@ test_that("compile (compressed formulation, multiple zones, scalar budget)", {
     f <- match(targs$feature[i], feature_names(sim_features_zones))
     counter <- counter + 1
     for (z in zs)
-      m[counter, ((z - 1) * n_pu) + seq_len(n_pu)] <- p$data$rij[[z]][f, ]
+      m[counter, ((z - 1) * n_pu) + seq_len(n_pu)] <- p$data$rij_matrix[[z]][f, ]
     m[counter, (n_z * n_pu) + i] <- -1 * targs$target[i]
   }
   counter <- counter + 1
@@ -322,7 +322,7 @@ test_that("solve (compressed formulation, multiple zones, scalar budget)", {
                            feature_names = targs$feature)) %>%
        add_max_phylo_div_objective(budget = budget, tree = tr) %>%
        add_manual_targets(targs) %>%
-       add_default_solver(gap = 0)
+       add_default_solver(gap = 0, verbose = FALSE)
   # solve problem
   s <- solve(p)
   # test for correct solution
@@ -380,7 +380,7 @@ test_that("compile (compressed formulation, multiple zones, vector budget)", {
     f <- match(targs$feature[i], feature_names(sim_features_zones))
     counter <- counter + 1
     for (z in zs)
-      m[counter, ((z - 1) * n_pu) + seq_len(n_pu)] <- p$data$rij[[z]][f, ]
+      m[counter, ((z - 1) * n_pu) + seq_len(n_pu)] <- p$data$rij_matrix[[z]][f, ]
     m[counter, (n_z * n_pu) + i] <- -1 * targs$target[i]
   }
   for (i in seq_along(b)) {
@@ -441,7 +441,7 @@ test_that("solve (compressed formulation, multiple zones, vector budget)", {
                            feature_names = targs$feature)) %>%
        add_max_phylo_div_objective(budget = budget, tree = tr) %>%
        add_manual_targets(targs) %>%
-       add_default_solver(gap = 0)
+       add_default_solver(gap = 0, verbose = FALSE)
   # solve problem
   s <- solve(p)
   # test for correct solution
@@ -519,7 +519,7 @@ test_that("compile (expanded formulation, multiple zones, scalar budget)", {
       for (pu in seq_len(n_pu)) {
         col <- (n_pu * n_z) + ((z - 1) * n_f * n_pu) +
                ((f - 1) * n_pu) + pu
-        m[counter, col] <- p$data$rij[[z]][f, pu]
+        m[counter, col] <- p$data$rij_matrix[[z]][f, pu]
       }
       col <- (n_pu * n_z) + (n_pu * n_f * n_z) + i
       m[counter, col] <- -1 * targs$target[i]
@@ -581,7 +581,7 @@ test_that("solve (expanded formulation, multiple zones, scalar budget)", {
                            feature_names = targs$feature)) %>%
        add_max_phylo_div_objective(budget = budget, tree = tr) %>%
        add_manual_targets(targs) %>%
-       add_default_solver(gap = 0)
+       add_default_solver(gap = 0, verbose = FALSE)
   # solve problem
   s <- solve(p, compressed_formulation = FALSE)
   # test for correct solution
@@ -662,7 +662,7 @@ test_that("compile (expanded formulation, multiple zones, vector budget)", {
       for (pu in seq_len(n_pu)) {
         col <- (n_pu * n_z) + ((z - 1) * n_f * n_pu) +
                ((f - 1) * n_pu) + pu
-        m[counter, col] <- p$data$rij[[z]][f, pu]
+        m[counter, col] <- p$data$rij_matrix[[z]][f, pu]
       }
       col <- (n_pu * n_z) + (n_pu * n_f * n_z) + i
       m[counter, col] <- -1 * targs$target[i]
@@ -726,7 +726,7 @@ test_that("solve (expanded formulation, multiple zones, vector budget)", {
                            feature_names = targs$feature)) %>%
        add_max_phylo_div_objective(budget = budget, tree = tr) %>%
        add_manual_targets(targs) %>%
-       add_default_solver(gap = 0)
+       add_default_solver(gap = 0, verbose = FALSE)
   # solve problem
   s <- solve(p, compressed_formulation = FALSE)
   # test for correct solution
