@@ -284,6 +284,74 @@ test_that("Spatial (multiple zone)", {
   expect_equivalent(r, pu[, c("rc_1", "rc_2")])
 })
 
+test_that("sf (single zone)", {
+  skip_on_cran()
+  skip_on_travis()
+  skip_on_appveyor()
+  skip_if_not(any_solvers_installed())
+  # create data
+  data(sim_pu_polygons)
+  pu <- sim_pu_polygons[1:4, ]
+  pu@data <- data.frame(id = seq_len(4),
+                        cost = c(10, 2, NA, 3),
+                        spp1 = c(0, 0, 0, 1),
+                        spp2 = c(10, 5, 10, 6))
+  pu <- sf::st_as_sf(pu)
+  # create problem
+  p <-
+    problem(pu, c("spp1", "spp2"), cost_column = "cost") %>%
+    add_min_set_objective() %>%
+    add_absolute_targets(c(1, 10)) %>%
+    add_binary_decisions() %>%
+    add_default_solver(gap = 0, verbose = FALSE)
+  # create a solution
+  pu$solution <- c(0, 1, NA, 1)
+  # calculate replacement costs
+  r <- replacement_cost(p, pu[, "solution"], rescale = FALSE)
+  # create correct result
+  pu$rc <- c(0, 8, NA, Inf)
+  # run tests
+  expect_equivalent(r, pu[, "rc"])
+})
+
+test_that("sf (multiple zone)", {
+  skip_on_cran()
+  skip_on_travis()
+  skip_on_appveyor()
+  skip_if_not(any_solvers_installed())
+  # create data
+  data(sim_pu_polygons)
+  pu <- sim_pu_polygons[1:8, ]
+  pu@data <- data.frame(id = seq_len(8),
+                        cost_1 = c(1,  2,  NA, 3, 100, 100, NA, 100),
+                        cost_2 = c(10, 10, 10, 10,  4,   1, NA, 10),
+                        spp1_1 = c(1,  2, 0, 0, 0, 0,  0, 0),
+                        spp2_1 = c(NA, 0, 1, 1, 0, 0,  0, 0),
+                        spp1_2 = c(1,  0, 0, 0, 1, 0,  0, 1),
+                        spp2_2 = c(0,  0, 0, 0, 0, 10, 0, 0))
+  targets <- matrix(c(1, 1, 1, 0), nrow = 2, ncol = 2)
+  pu <- sf::st_as_sf(pu)
+  # create problem
+  p <-
+    problem(pu, zones(c("spp1_1", "spp2_1"), c("spp1_2", "spp2_2")),
+            c("cost_1", "cost_2")) %>%
+    add_min_set_objective() %>%
+    add_absolute_targets(targets) %>%
+    add_binary_decisions() %>%
+    add_default_solver(gap = 0, verbose = FALSE)
+  # create a solution
+  pu$solution_1 <- c(1, 0, NA, 1, 0, 0, NA, 0)
+  pu$solution_2 <- c(0, 0, 0, 0, 1, 0, NA, 0)
+  # calculate replacement costs
+  r <- replacement_cost(p, pu[, c("solution_1", "solution_2")],
+                        rescale = FALSE)
+  # create correct result
+  pu$rc_1 <- c(1, 0, NA, Inf, 0, 0, NA, 0)
+  pu$rc_2 <- c(0, 0, 0, 0, 6, 0, NA, 0)
+  # run tests
+  expect_equivalent(r, pu[, c("rc_1", "rc_2")])
+})
+
 test_that("Raster (single zone)", {
   skip_on_cran()
   skip_on_travis()
